#define USE_ARDUINO_INTERRUPTS true
#include <PulseSensorPlayground.h>
#include <LiquidCrystal.h>
#include <Adafruit_MPU6050.h>
#include <Adafruit_Sensor.h>
#include <Wire.h>

Adafruit_MPU6050 mpu;

int Contrast = 50;
LiquidCrystal lcd(12, 11, 5, 4, 3, 2);

const int PulseWire = 0;
const int LED13 = 13;
int Threshold = 550;
float myBPM = 80;
PulseSensorPlayground pulseSensor;

const int button = 7;
int buttonState = 0;
int prevButtonState = 0;
int counter = 0;

float distance = 0;
float steps = 0;
float calories = 0;
float new_calories = 0;

float age = 22;
float kg = 85;

void setup_pulse_sensor() {
  pulseSensor.analogInput(PulseWire);
  pulseSensor.blinkOnPulse(LED13);
  pulseSensor.setThreshold(Threshold);

  // Double-check the "pulseSensor" object was created and "began" seeing a signal.
  if (pulseSensor.begin()) {
    Serial.println("We created a pulseSensor Object !");
  }
}

void setup_accelerometer() {
   while (!Serial)
    delay(10); // will pause Zero, Leonardo, etc until serial console opens

  Serial.println("Adafruit MPU6050 test!");

  // Try to initialize!
  if (!mpu.begin()) {
    Serial.println("Failed to find MPU6050 chip");
    while (1) {
      delay(10);
    }
  }

  //setupt motion detection
  mpu.setHighPassFilter(MPU6050_HIGHPASS_0_63_HZ);
  mpu.setMotionDetectionThreshold(1);
  mpu.setMotionDetectionDuration(20);
  mpu.setInterruptPinLatch(true);  // Keep it latched.  Will turn off when reinitialized.
  mpu.setInterruptPinPolarity(true);
  mpu.setMotionInterrupt(true);

  delay(100);
  
}


void setup() {

  Serial.begin(9600);
  pinMode(button, INPUT_PULLUP);
  
  setup_pulse_sensor();
  setup_accelerometer();

  //analogWrite(6, Contrast);
  lcd.begin(16, 2);
  

}

void get_BPM() {

  //get BPM
  float new_BPM = pulseSensor.getBeatsPerMinute();
  if (new_BPM != 0)
      myBPM = new_BPM;
  if (new_BPM  < 60 && new_BPM > 0)
      myBPM = 2 * new_BPM;
  if (new_BPM > 160)
      myBPM = 0.5 * new_BPM;
    
}

void display_info(int buttonState) {

  if (buttonState % 4 == 0) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Distance: ");
    lcd.setCursor(0, 1);
    lcd.print(distance , 1);
  }
  else if (buttonState % 4 == 1) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Steps: ");
    lcd.setCursor(0, 1);
    lcd.print(int(steps));
  }
  else if (buttonState % 4 == 2) {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("Calories: ");
    lcd.setCursor(0, 1);
    lcd.print(int(calories));
  }
  else {
    lcd.clear();
    lcd.setCursor(0, 0);
    lcd.print("BPM: ");
    lcd.setCursor(0, 1);
    lcd.print(myBPM);
  }
}

int i = 200;
float prev_v = 0;
float curr_v;
float prev_d = 0;
float dist;

float comp_accel(sensors_event_t a1, sensors_event_t a2){
   float deltaX, deltaY, deltaZ;
   float deltaAccel;
   
   deltaX = a2.acceleration.x - a1.acceleration.x;
   deltaY = a2.acceleration.y - a1.acceleration.y;
   deltaZ = a2.acceleration.z - a1.acceleration.z;

   deltaAccel = sqrt(deltaX * deltaX + deltaY * deltaY);
   deltaAccel = sqrt(deltaZ * deltaZ + deltaAccel * deltaAccel);

   if(deltaX + deltaY + deltaZ < 0 )
      return deltaAccel;
   else
      return (-1) * deltaAccel;
    
}


float compute_calories(float BPM){
  float timp = round(millis()/1000);
  float timp_minutes = timp / 60;
  float CB = timp_minutes * (0.6309 * BPM + 0.1988 * kg + 0.2017 * age - 55.0969) / 4.184;
  
  return CB;
}

void loop() {
  buttonState = digitalRead(button);
  if (buttonState == 1 && prevButtonState == 0) {
    display_info(counter);
    prevButtonState = 1;
    counter++;
  }

  if (buttonState == 0 && prevButtonState == 1) {
    prevButtonState = 0;
  }
  
  
  
  get_BPM();
  if(mpu.getMotionInterruptStatus()) {
    float start_t = millis();
    
    sensors_event_t a1, g1, temp1;
    sensors_event_t a2, g2, temp2;
    
    
    float mediumAccel = 0;
    for(int i = 0; i < 1; i++){
      mpu.getEvent(&a1, &g1, &temp1);
      mpu.getEvent(&a2, &g2, &temp2);
      float deltaAccel = comp_accel(a1, a2);      
      mediumAccel += deltaAccel;
    }
    mediumAccel /= 10;
 
    float stop_t = millis();   
    curr_v = abs(prev_v + mediumAccel);
    float deltaT = (stop_t - start_t)/1000;
    
    distance = prev_d + deltaT * curr_v + 0.5 * (mediumAccel * deltaT * deltaT);
    steps = round(distance / 0.7);
    new_calories = round(compute_calories(myBPM)); 
    if (new_calories > calories)
        calories = new_calories;
    

    display_info(counter);

    prev_v = curr_v;
    prev_d = distance;
  }
  
}
